=======
History
=======

0.8.4 (2020-03-23)
------------------

* New plugin architecture, combined with a cookiecutter definition for creating new ones
* Removed several in-progress job/submitter types to plugins

0.8.3 (2020-03-13)
------------------

* ``prfr`` now recognizes site config if user config doesn't exist

0.8.2 (2020-03-12)
------------------

* Fixed tests, general bugfixes

0.8.1 (2020-03-11)
------------------

* Improved service files.

0.8.0 (2020-03-09)
------------------

* First release on PyPI.
